@@ -6,7 +6,7 @@
  * Copyright (C) 2000, 2002 - Chema Celorio, Paolo Maggi
  * Copyright (C) 2003-2005 - Paolo Maggi
  *
- * Copyright (C) 2014, 2015, 2017, 2018 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright (C) 2014-2020 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * GNOME LaTeX is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -91,59 +91,6 @@ latexila_utils_get_pixbuf_from_icon_name (const gchar *icon_name,
 	return pixbuf;
 }
 
-/**
- * latexila_utils_file_query_exists_async:
- * @file: a #GFile.
- * @cancellable: a #GCancellable.
- * @callback: the callback to call when the operation is finished.
- * @user_data: the data to pass to the callback function.
- *
- * The asynchronous version of g_file_query_exists(). When the operation is
- * finished, @callback will be called. You can then call
- * latexila_utils_file_query_exists_finish() to get the result of the operation.
- */
-void
-latexila_utils_file_query_exists_async (GFile               *file,
-					GCancellable        *cancellable,
-					GAsyncReadyCallback  callback,
-					gpointer             user_data)
-{
-	g_file_query_info_async (file,
-				 G_FILE_ATTRIBUTE_STANDARD_TYPE,
-				 G_FILE_QUERY_INFO_NONE,
-				 G_PRIORITY_DEFAULT,
-				 cancellable,
-				 callback,
-				 user_data);
-}
-
-/**
- * latexila_utils_file_query_exists_finish:
- * @file: a #GFile.
- * @result: a #GAsyncResult.
- *
- * Finishes the operation started with latexila_utils_file_query_exists_async().
- * There is no output #GError parameter, so you should check if the operation
- * has been cancelled (in which case %FALSE will be returned).
- *
- * Returns: %TRUE if the file exists and the operation hasn't been cancelled,
- * %FALSE otherwise.
- */
-gboolean
-latexila_utils_file_query_exists_finish (GFile        *file,
-					 GAsyncResult *result)
-{
-	GFileInfo *info = g_file_query_info_finish (file, result, NULL);
-
-	if (info != NULL)
-	{
-		g_object_unref (info);
-		return TRUE;
-	}
-
-	return FALSE;
-}
-
 static gboolean
 default_document_viewer_is_evince (const gchar *uri)
 {
@@ -264,54 +211,6 @@ latexila_utils_get_dialog_component (const gchar *title,
 	return GTK_WIDGET (grid);
 }
 
-/**
- * latexila_utils_create_parent_directories:
- * @file: a file
- * @error: (out) (optional): a location to a %NULL #GError, or %NULL.
- *
- * Synchronously creates parent directories of @file, so that @file can be
- * saved.
- *
- * Returns: whether the directories are correctly created. %FALSE is returned on
- * error.
- */
-gboolean
-latexila_utils_create_parent_directories (GFile   *file,
-					  GError **error)
-{
-	GFile *parent;
-	GError *my_error = NULL;
-
-	g_return_val_if_fail (G_IS_FILE (file), FALSE);
-	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
-
-	parent = g_file_get_parent (file);
-
-	if (parent == NULL)
-	{
-		return TRUE;
-	}
-
-	g_file_make_directory_with_parents (parent, NULL, &my_error);
-	g_object_unref (parent);
-
-	if (my_error != NULL)
-	{
-		if (g_error_matches (my_error, G_IO_ERROR, G_IO_ERROR_EXISTS))
-		{
-			g_error_free (my_error);
-			return TRUE;
-		}
-		else
-		{
-			g_propagate_error (error, my_error);
-			return FALSE;
-		}
-	}
-
-	return TRUE;
-}
-
 /**
  * latexila_utils_join_widgets:
  * @widget_top: the #GtkWidget at the top.
@@ -323,7 +222,8 @@ latexila_utils_create_parent_directories (GFile   *file,
  * @widget_bottom.
  */
 /* TODO try to simply add the GTK_STYLE_CLASS_LINKED class to the
- * GtkStyleContext of a GtkGrid.
+ * GtkStyleContext of a GtkBox. Test also in RTL (right-to-left) text, although
+ * here it's a vertical container so it should not matter.
  */
 GtkWidget *
 latexila_utils_join_widgets (GtkWidget *widget_top,
@@ -430,7 +330,7 @@ migrate_latexila_to_gnome_latex_copy_file (GFile *latexila_file,
 {
 	GError *error = NULL;
 
-	latexila_utils_create_parent_directories (glatex_file, &error);
+	tepl_utils_create_parent_directories (glatex_file, NULL, &error);
 	if (error != NULL)
 	{
 		goto out;
